@@ -222,10 +222,10 @@ export class YargsParser {
       let value: string
 
       // any unknown option (except for end-of-options, "--")
-      if (arg !== '--' && isUnknownOptionAsArg(arg)) {
+      if (arg !== '--' && /^-/.test(arg) && isUnknownOptionAsArg(arg)) {
         pushPositional(arg)
       // ---, ---=, ----, etc,
-      } else if (truncatedArg.match(/---+(=|$)/)) {
+      } else if (truncatedArg.match(/^---+(=|$)/)) {
         // options without key name are invalid.
         pushPositional(arg)
         continue
